import math

class AssemblerInterpreter:
    def __init__(self):
        self.variables = {}
        self.labels = {}
        self.program = []
        self.pc = 0

    def parse_program(self, code):
        lines = code.split('\n')
        for line in lines:
            line = line.strip()
            if line:
                if ':' in line:
                    label, _ = line.split(':')
                    self.labels[label] = len(self.program)
                    line = _.strip()
                self.program.append(line)

    def run(self):
        while self.pc < len(self.program):
            instruction = self.program[self.pc].split()
            opcode = instruction[0]
            match opcode:
                case 'stop':
                    break
                case'store':
                    self.store(instruction[1:])
                case 'add' | 'sub' | 'mul' | 'div':
                    self.perform_arithmetic(opcode, instruction[1:])
                case _ if opcode.startswith('if'):
                    self.compare_and_jump(opcode, instruction[1:])
                case 'out':
                    self.output(instruction[1])

            self.pc += 1

    def store(self, args):
        if len(args) == 2:
            number, variable = args
            try:
                self.variables[variable] = float(number)
            except ValueError:
                self.variables[variable] = 0

    def perform_arithmetic(self, opcode, args):
        if len(args) == 3:
            source, operand, target = args
            try:
                source_val = float(source) if '.' in source else self.variables.get(source, 0)
                operand_val = float(operand) if '.' in operand else self.variables.get(operand, 0)
                match opcode:
                    case 'add':
                        result = source_val + operand_val
                    case 'sub':
                        result = source_val - operand_val
                    case 'mul':
                        result = source_val * operand_val
                    case 'div':
                        if operand_val != 0:
                            result = source_val / operand_val
                        else:
                            result = math.inf
                self.variables[target] = result
            except ValueError:
                pass

    def compare_and_jump(self, opcode, args):
        if len(args) == 3:
            source, operand, label = args
            source_val = float(source) if '.' in source else self.variables.get(source, 0)
            operand_val = float(operand) if '.' in operand else self.variables.get(operand, 0)

            if opcode == 'ifeq' and source_val == operand_val:
                self.pc = self.labels.get(label, self.pc)-1
            elif opcode == 'ifne' and source_val != operand_val:
                self.pc = self.labels.get(label, self.pc)-1
            elif opcode == 'ifgt' and source_val > operand_val:
                self.pc = self.labels.get(label, self.pc)-1
            elif opcode == 'ifge' and source_val >= operand_val:
                self.pc = self.labels.get(label, self.pc)-1
            elif opcode == 'iflt' and source_val < operand_val:
                self.pc = self.labels.get(label, self.pc)-1
            elif opcode == 'ifle' and source_val <= operand_val:
                self.pc = self.labels.get(label, self.pc)-1

    def output(self, variable):
        print(self.variables.get(variable, 0))

code = []
try:
    while True:
        code.append(input())
except EOFError:
    pass
code = '\n'.join(code)
interpreter = AssemblerInterpreter()
interpreter.parse_program(code)
interpreter.run()